
(function ($) {
    'use strict';

    $( document ).ready( function() {
        singleProductAddToCart();
        liveViewsVisitors();
        
    } );

    function singleProductAddToCart() {
        // wc_add_to_cart_params is required to continue, ensure the object exists.
        if ( typeof wc_add_to_cart_params === 'undefined' ) {
            return false;
        }

        /**
         * Ajax add to cart.
         * button query selector to compatible with Lumise add on.
         */
        $( document ).on( 'click', 'button.single_add_to_cart_button.ajax_add_to_cart.button-buy-now', function( evt ) {
            evt.preventDefault();

            var $thisButton = $( this );

            if ( $thisButton.hasClass( 'disabled' ) ) { // Variation select required.
                return false;
            }

            if ( $thisButton.hasClass( 'woosb-disabled' ) ) { // Smart Bundle select required.
                return false;
            }

            var $variationsForm = $thisButton.closest( 'form.cart' ),
                productID       = $variationsForm.find( '[name=add-to-cart]' ).val(),
                variationID     = $variationsForm.find( 'input[name=variation_id]' ).val(),
                quantity        = $variationsForm.find( '.quantity .qty[name=quantity]' ).val();

            if ( 'add-to-cart' === $thisButton.attr( 'name' ) ) {
                productID = $thisButton.val();
            }

            if ( 0 === productID ) {
                return;
            }

            var data = {
                product_id: productID,
                variation_id: variationID,
            };

            $variationsForm.serializeArray().map( function( attr ) {
                if ( attr.name !== 'add-to-cart' ) {
                    if ( attr.name.endsWith( '[]' ) ) {
                        let name = attr.name.substring( 0, attr.name.length - 2 );
                        if ( ! (
                            name in data
                        ) ) {
                            data[name] = [];
                        }
                        data[name].push( attr.value );
                    } else {
                        data[attr.name] = attr.value;
                    }
                }
            } );

            // Custom quantity per button.
            if ( $thisButton.attr( 'data-qty' ) ) {
                quantity = parseInt( $thisButton.attr( 'data-qty' ) );
            }
            data.quantity = quantity;

            $thisButton.removeClass( 'added' ).addClass( 'loading updating-icon' );

            // Trigger event.
            $( 'body' ).trigger( 'adding_to_cart', [ $thisButton, data ] );

            // Ajax action.
            $.post( wc_add_to_cart_params.wc_ajax_url.toString().replace( '%%endpoint%%', 'tmcore_add_to_cart' ), data, function( response ) {
                if ( ! response ) {
                    return;
                }

                if ( response.error && response.product_url ) {
                    window.location = response.product_url;
                    return;
                }

                // Redirect to checkout for Buy Now button.
                var redirect = $thisButton.data( 'redirect' );
                if ( redirect && '' !== redirect ) {
                    window.location = redirect;
                    return;
                }

                // Redirect to cart option.
                if ( wc_add_to_cart_params.cart_redirect_after_add === 'yes' ) {
                    window.location = wc_add_to_cart_params.cart_url;
                    return;
                }

                // Trigger event so themes can refresh other areas.
                $( document.body ).trigger( 'added_to_cart', [
                    response.fragments, response.cart_hash, $thisButton
                ] );

            } ).always( function() {
                $thisButton.addClass( 'added' ).removeClass( 'loading updating-icon' );
            } );
        } );
    }

    function liveViewsVisitors() {
		var $wrap = $( '#tmcore-live-viewing-visitors' );

		if ( 0 >= $wrap.length ) {
			return;
		}
		var {
			    min,
			    max,
			    duration,
			    labels
		    }     = $wrap.data( 'settings' );
		var $text = $wrap.find( '.text-wrapper' );
		min       = parseInt( min );
		max       = parseInt( max );

		setInterval( function() {
			var current = Math.floor( Math.random() * (max - min + 1) ) + min,
			    text    = current > 1 ? labels.plural : labels.singular;
			text        = text.replace( '%s', '<span class="count">' + current + '</span>' );
			$text.html( text );
		}, duration );
	}


})(jQuery);


// wishlist counter
jQuery(document).ready(function($) {
    $('body').on('woosw_change_count', function(event, count) {
        $('.header-wishlist-total').html(count);
    });
});

// Copy url to share for social share
jQuery(document).ready(function($) {
    // Copy url
    $("#copyButton").click(function() {
        var copyLink = $("#copy_permalink");
        copyLink.select();
        document.execCommand("copy"); // execute copy command

        // Change button text
        $("#copyButton .copied").show();
        $("#copyButton .copy").hide();
        // Reset button text after 3 seconds
        setTimeout(function() {
            $("#copyButton .copied").hide();
            $("#copyButton .copy").show();
        }, 3000);
        
    });
});

// stop autoscroll to bottom on checkout and cart
jQuery(document).ready(function($) {
    $(document).ajaxComplete(function() {
        if ($('body').hasClass('woocommerce-checkout') || $('body').hasClass('woocommerce-cart')) {
            jQuery( 'html, body' ).stop();
        }
    });
});

(function ($) {
    'use strict';
	function freeShippingBarContent () {
		$( document.body ).on('wc_fragments_loaded wc_fragments_refreshed', function () {
            
            if ( !$(document.body).hasClass('woocommerce-checkout') ) {
				return;
			}

            var $fsbValuesMini = $('.base-mini-cart-refresh .tmcore-fsb');
            //var $fsbValuesCart = $('.woocommerce-cart .content-area .tmcore-fsb');
            var $fsbValuesCheck = $('form.checkout .tmcore-fsb');
            var isFSBActive = false;

            if ( $fsbValuesMini.length > 0 ) {
            
                isFSBActive = true;
                var	message		= $fsbValuesMini.data('message'),
                    percent		= $fsbValuesMini.data('percent'),
                    classes		= $fsbValuesMini.data('classes');
                    

            } else if ( $fsbValuesCheck.length > 0 ) {

                isFSBActive = true;
                var	message		= $fsbValuesCheck.data('message'),
                    percent		= $fsbValuesCheck.data('percent'),
                    classes		= $fsbValuesCheck.data('classes');
            }

            if ( isFSBActive == true ) {
                
                $('.tmcore-fsb').css('--fsb-percent', percent);
			    $('.tmcore-fsb-message').html(message);
                $('.tmcore-fsb').removeClass('tm-is-success tm-is-unreached tm-progress-full').addClass(classes);

            }
            if ( $fsbValuesCheck.length > 0 ) {                
                $fsbValuesCheck.data('percent', percent);
                $fsbValuesCheck.data('classes', classes);
            }
		});

		$(document.body).on('tmcore_off_canvas_closed added_to_cart', function (e) {
            $('.tmcore-fsb').removeClass('tmcore-fsb--preload');
        });        
	}
    $(function () {
		freeShippingBarContent();
    });

})(jQuery);