<?php

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Text_Stroke;

/**
 * Elementor image box widget.
 *
 * Elementor widget that displays an image, a headline and a text.
 *
 * @since 1.0.0
 */
class TemplateMelaCore_Elementor_Marquee extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve image box widget name.
	 *
	 * @return string Widget name.
	 * @since  1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tmcore-marquee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve image box widget title.
	 *
	 * @return string Widget title.
	 * @since  1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return __( 'TM Marquee', 'templatemela-core' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve image box widget icon.
	 *
	 * @return string Widget icon.
	 * @since  1.0.0
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'eicon-animation';
	}

	public function get_categories() {
		return array( 'tmcore-addons' );
	}

	public function get_script_depends() {
        return [
			'imagesloaded',
            'tmcore-elementor-marquee',
        ];
    }

	/**
	 * Register marquee widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->section_content();
		$this->section_style();
	}

	protected function section_content() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'templatemela-core' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'type',
			[
				'label'   => esc_html__( 'Type', 'templatemela-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'icon-text',
				'options' => [
					'icon-text' => esc_html__( 'Icon & text', 'templatemela-core' ),
					'image'     => esc_html__( 'Image', 'templatemela-core' ),
				],
			]
		);

        $repeater->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'templatemela-core' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value'   => 'fa fa-star',
					'library' => 'fa-solid',
				],
				'conditions' => [
					'terms' => [
						[
							'name'  => 'type',
							'value' => 'icon-text',
						],
					],
				],
			]
		);

		$repeater->add_control(
			'text', [
				'label' => esc_html__( 'Text', 'templatemela-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'conditions' => [
					'terms' => [
						[
							'name'  => 'type',
							'value' => 'icon-text',
						],
					],
				],
			]
		);

		$repeater->add_responsive_control(
			'image',
			[
				'label'    => __( 'Image', 'templatemela-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'conditions' => [
					'terms' => [
						[
							'name'  => 'type',
							'value' => 'image',
						],
					],
				],
			]
		);

		$repeater->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'text_stroke',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .tmcore-marquee_text',
			]
		);

		$repeater->add_control(
			'text_repeater_color',
			[
				'label'      => esc_html__( 'Color', 'templatemela-core' ),
				'type'       => Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .tmcore-marquee_text' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'items',
			[
				'label' => esc_html__( 'Items', 'templatemela-core' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
                        'text' => esc_html__( 'Exclusive Seasonal Sale: Save Up to 50%', 'templatemela-core' ),
					],
					[
                        'text' => esc_html__( 'Expert Customer Online Service', 'templatemela-core' ),
					],
					[
                        'text' => esc_html__( 'Free Shipping order over $99', 'templatemela-core' ),
					],
				],
			]
		);

		$this->add_control(
			'speed',
			[
				'label'   => __( 'Speed(s)', 'templatemela-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => '25',
				'min'     => 1,
				'max'	  => 1000,
				'step'    => 1,
				'frontend_available' => true,
			]
		);

		$this->end_controls_section();
	}

	protected function section_style() {
		// Style
		$this->start_controls_section(
			'section_style',
			[
				'label'     => __( 'Content', 'templatemela-core' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'hover_pause',
			[
				'label'     => esc_html__( 'Hover stop', 'templatemela-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'templatemela-core' ),
				'label_off' => esc_html__( 'No', 'templatemela-core' ),
				'default'   => 'yes',
			]
		);

		$this->add_responsive_control(
			'padding',
			[
				'label'      => __( 'Padding', 'templatemela-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'body[dir=rtl] {{WRAPPER}} .tmcore-marquee' => 'padding: {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{RIGHT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'gap',
			[
				'label'      => esc_html__( 'Gap', 'templatemela-core' ),
				'type'       => Controls_Manager::SLIDER,
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'size_units' => [ 'px' ],
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee_items' => 'gap: {{SIZE}}{{UNIT}}; margin-right: {{SIZE}}{{UNIT}};',
					'body[dir=rtl] {{WRAPPER}} .tmcore-marquee_items' => 'gap: {{SIZE}}{{UNIT}}; margin-left: {{SIZE}}{{UNIT}}; margin-right: 0;',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label'      => esc_html__( 'Background Color', 'templatemela-core' ),
				'type'       => Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name'      => 'image',
				'default'   => 'full',
			]
		);

		$this->add_control(
			'icon_heading',
			[
				'label' => esc_html__( 'Icon', 'templatemela-core' ),
				'type'  => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label'      => esc_html__( 'Size', 'templatemela-core' ),
				'type'       => Controls_Manager::SLIDER,
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'size_units' => [ 'px' ],
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee_icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label'      => esc_html__( 'Color', 'templatemela-core' ),
				'type'       => Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee_icon' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'spacing',
			[
				'label'      => esc_html__( 'Spacing', 'templatemela-core' ),
				'type'       => Controls_Manager::SLIDER,
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'size_units' => [ 'px' ],
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee_item' => 'gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'text_heading',
			[
				'label' => esc_html__( 'Text', 'templatemela-core' ),
				'type'  => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'text_typography',
				'selector' => '{{WRAPPER}} .tmcore-marquee_text',
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'      => esc_html__( 'Color', 'templatemela-core' ),
				'type'       => Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} .tmcore-marquee_text' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
	}


	protected function render() {
		$settings = $this->get_settings_for_display();

		$classes = [
			'tmcore-marquee',
			'tmcore-elementor_marquee',
			$settings['hover_pause'] == 'yes' ? 'tmcore-marquee-hover-stop' : '',
		];

        $this->add_render_attribute( 'wrapper', 'class', $classes );
        $this->add_render_attribute( 'inner', 'class', [ 'tmcore-marquee_inner' ] );
        $this->add_render_attribute( 'items', 'class', [ 'tmcore-marquee_items', 'tmcore-marquee-original' ] );
		$this->add_render_attribute( 'items1', 'class', [ 'tmcore-marquee_items', 'tmcore-marquee-duplicate' ] );
		$this->add_render_attribute( 'items2', 'class', [ 'tmcore-marquee_items', 'tmcore-marquee-duplicate' ] );
        $this->add_render_attribute( 'icon', 'class', [ 'tmcore-marquee_icon', 'base-svg-iconset' ] );
        $this->add_render_attribute( 'text', 'class', [ 'tmcore-marquee_text' ] );
    ?>
        <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
            <div <?php echo $this->get_render_attribute_string( 'inner' ); ?>>
				<div <?php echo $this->get_render_attribute_string( 'items' ); ?>>
					<?php foreach( $settings['items'] as $index => $item ) : ?>
						<?php
							$item_key = $this->get_repeater_setting_key( 'item', 'elementor-marquee', $index );
							$this->add_render_attribute( $item_key, 'class', [ 'tmcore-marquee_item', 'elementor-repeater-item-' . esc_attr( $item['_id'] ) ] );
						?>
						<div <?php echo $this->get_render_attribute_string( $item_key ); ?>>
							<?php if( $item['type'] == 'image' ) : ?>
								<?php
									$image_args = [
										'image'        => ! empty( $item['image'] ) ? $item['image'] : '',
										'image_tablet' => ! empty( $item['image_tablet'] ) ? $item['image_tablet'] : '',
										'image_mobile' => ! empty( $item['image_mobile'] ) ? $item['image_mobile'] : '',
									];
								?>
								<?php echo Group_Control_Image_Size::get_attachment_image_html( $image_args ); ?>
							<?php else : ?>
								<?php if( ! empty( $item['icon'] ) && ! empty( $item['icon']['value'] ) ) : ?>
									<span <?php echo $this->get_render_attribute_string( 'icon' ); ?>>
										<?php Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
									</span>
								<?php endif; ?>
								<div <?php echo $this->get_render_attribute_string( 'text' ); ?>>
									<?php echo wp_kses_post( $item['text'] ); ?>
								</div>
							<?php endif; ?>
						</div>
					<?php endforeach; ?>
				</div>

				<div <?php echo $this->get_render_attribute_string( 'items1' ); ?> style="--tm-marquee-index: 1;">
					<?php foreach( $settings['items'] as $index => $item ) : ?>
						<?php
							$item_key = $this->get_repeater_setting_key( 'item', 'elementor-marquee', $index );
							$this->add_render_attribute( $item_key, 'class', [ 'tmcore-marquee_item', 'elementor-repeater-item-' . esc_attr( $item['_id'] ) ] );
						?>
						<div <?php echo $this->get_render_attribute_string( $item_key ); ?>>
							<?php if( $item['type'] == 'image' ) : ?>
								<?php
									$image_args = [
										'image'        => ! empty( $item['image'] ) ? $item['image'] : '',
										'image_tablet' => ! empty( $item['image_tablet'] ) ? $item['image_tablet'] : '',
										'image_mobile' => ! empty( $item['image_mobile'] ) ? $item['image_mobile'] : '',
									];
								?>
								<?php echo Group_Control_Image_Size::get_attachment_image_html( $image_args ); ?>
							<?php else : ?>
								<?php if( ! empty( $item['icon'] ) && ! empty( $item['icon']['value'] ) ) : ?>
									<span <?php echo $this->get_render_attribute_string( 'icon' ); ?>>
										<?php Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
									</span>
								<?php endif; ?>
								<div <?php echo $this->get_render_attribute_string( 'text' ); ?>>
									<?php echo wp_kses_post( $item['text'] ); ?>
								</div>
							<?php endif; ?>
						</div>
					<?php endforeach; ?>
				</div>

				<div <?php echo $this->get_render_attribute_string( 'items2' ); ?> style="--tm-marquee-index: 2;">
					<?php foreach( $settings['items'] as $index => $item ) : ?>
						<?php
							$item_key = $this->get_repeater_setting_key( 'item', 'elementor-marquee', $index );
							$this->add_render_attribute( $item_key, 'class', [ 'tmcore-marquee_item', 'elementor-repeater-item-' . esc_attr( $item['_id'] ) ] );
						?>
						<div <?php echo $this->get_render_attribute_string( $item_key ); ?>>
							<?php if( $item['type'] == 'image' ) : ?>
								<?php
									$image_args = [
										'image'        => ! empty( $item['image'] ) ? $item['image'] : '',
										'image_tablet' => ! empty( $item['image_tablet'] ) ? $item['image_tablet'] : '',
										'image_mobile' => ! empty( $item['image_mobile'] ) ? $item['image_mobile'] : '',
									];
								?>
								<?php echo Group_Control_Image_Size::get_attachment_image_html( $image_args ); ?>
							<?php else : ?>
								<?php if( ! empty( $item['icon'] ) && ! empty( $item['icon']['value'] ) ) : ?>
									<span <?php echo $this->get_render_attribute_string( 'icon' ); ?>>
										<?php Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
									</span>
								<?php endif; ?>
								<div <?php echo $this->get_render_attribute_string( 'text' ); ?>>
									<?php echo wp_kses_post( $item['text'] ); ?>
								</div>
							<?php endif; ?>
						</div>
					<?php endforeach; ?>
				</div>


            </div>
        </div>
    <?php
	}
}

$widgets_manager->register( new TemplateMelaCore_Elementor_Marquee() );
