<?php
/**
 * Layout functions and definitions.
 * by TemplateMela.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 */

use function Base\webapp;

/*
 * electronics Styles
 *
 */
function kartpul_electronics_enqueue_styles() {
    wp_enqueue_style( 'kartpul-electronics-style',
        TMTHEME_URL . 'layouts/electronics/style.css',
        array(),
        TMTHEME_VERSION
    );
    wp_enqueue_script( 'kartpul-electronics-js',
        TMTHEME_URL . 'layouts/electronics/custom.js',
        array(),
        TMTHEME_VERSION
    );
}
add_action(  'wp_enqueue_scripts', 'kartpul_electronics_enqueue_styles' , 9999 );

/**
 * Setup Layout Theme Defaults
 *
 * @param array  registered option defaults with base theme.
 * @return array
 */
function kartpul_layout_change_option_defaults( $defaults ) {
    $new_defaults = '{
        "post_content_style": "unboxed"
    }';
    $new_defaults = json_decode( $new_defaults, true );
    return wp_parse_args( $new_defaults, $defaults );
}
//add_filter( 'base_theme_options_defaults', 'kartpul_layout_change_option_defaults', 20 );

/*
 * Set Default Logo
 * Filter the output of logo to fix Googles Error about itemprop logo
 */
add_filter( 'base_custom_logo', 'kartpul_set_default_logo', 10, 2 );
function kartpul_set_default_logo( $html, $blog_id ) {

	$custom_logo_id = webapp()->option( 'custom_logo' );
    // if logo is uploaded then return
    if ( ! empty($custom_logo_id) ) {
        return $html;
    }
    $custom_logo_path = TMTHEME_URL . 'layouts/electronics/img/';
	$html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" itemprop="url">%2$s</a>',
        esc_url( home_url( '/' ) ),
        '<img decoding="async" width="174" height="50" src="' . $custom_logo_path . 'logo.svg"  class="logo" alt="' . get_bloginfo( 'name' ) . '" loading="lazy" srcset="' . $custom_logo_path . 'logo.svg 479w, ' . $custom_logo_path . 'logo.svg 200w" sizes="(max-width: 479px) 100vw, 479px" data-src="' . $custom_logo_path . 'logo.svg">');
        
        if ( webapp()->option( 'dark_mode_enable' ) && apply_filters( 'base_dark_mode_enable', true ) ) {
            $custom_logo_id = webapp()->option( 'dark_mode_logo' );
            // if dark logo is uploaded then return
            if ( ! empty($custom_logo_id) ) {
                return $html;
            }
            $html .= sprintf( '<a href="%1$s" class="brand" rel="home" itemprop="url">%2$s</a>',
            esc_url( home_url( '/' ) ),
            '<img decoding="async" width="174" height="50" src="' . $custom_logo_path . 'dark-logo.svg"  class="base-dark-mode-logo svg-logo-image logo" alt="' . get_bloginfo( 'name' ) . '" loading="lazy" srcset="' . $custom_logo_path . 'dark-logo.svg 479w, ' . $custom_logo_path . 'dark-logo.svg 200w" sizes="(max-width: 479px) 100vw, 479px" data-src="' . $custom_logo_path . 'dark-logo.svg">');

	    }
    return $html;	
}

// Override default theme icons
add_filter( 'base_svg_icon', 'kartpul_override_theme_icons', 10, 4 );
function kartpul_override_theme_icons( $output, $icon, $icon_title = '', $base = true, $aria = false ) {
    if ( 'shopping-cart' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="thebase-svg-icon thebase-shopping-cart-svg" fill="currentColor" version="1.1" xmlns="http://www.w3.org/2000/svg" width="24" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="0.5" viewBox="0 0 762.47 673.5"><path d="M600.86,489.86a91.82,91.82,0,1,0,91.82,91.82A91.81,91.81,0,0,0,600.86,489.86Zm0,142.93a51.12,51.12,0,1,1,51.11-51.11A51.12,51.12,0,0,1,600.82,632.79Z" transform="translate(0 0)"/><path d="M458.62,561.33H393.3a91.82,91.82,0,1,0-.05,40.92h65.37a20.46,20.46,0,0,0,0-40.92ZM303.7,632.79a51.12,51.12,0,1,1,51.12-51.11A51.11,51.11,0,0,1,303.7,632.79Z" transform="translate(0 0)"/><path d="M762.47,129.41a17.26,17.26,0,0,0-17.26-17.26H260.87a17.18,17.18,0,0,0-13.26,6.23,20.47,20.47,0,0,0-7.22,19.22l31.16,208a20.46,20.46,0,0,0,40.34-6.86L284.18,153.79H718.89l-37,256.4H221.59L166.75,15.06A17.26,17.26,0,0,0,147.42.14L123.7.12l0,.13H20.26a20.26,20.26,0,0,0,0,40.52H129.34l52.32,376.91,1,8.87c.1.85.15,1.71.19,2.57a23,23,0,0,0,1.35,6.76l.05.39a17.25,17.25,0,0,0,19.33,14.89l23.74.25,0-.27H698.19a24.33,24.33,0,0,0,3.44-.25,17.25,17.25,0,0,0,18.43-14.66l.18-1.27A22.94,22.94,0,0,0,721.3,428l.8-6.5,40.06-288.46a16.23,16.23,0,0,0,.16-2.59Z" transform="translate(0 0)"/>
        </svg></span>';
    }
    if ( 'account' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="thebase-svg-icon thebase-account-svg" fill="currentColor" stroke="currentColor" stroke-width="0" version="1.1" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 64 64"><title>Account</title><path d="M41.2452,33.0349a16,16,0,1,0-18.49,0A26.0412,26.0412,0,0,0,4,58a2,2,0,0,0,2,2H58a2,2,0,0,0,2-2A26.0412,26.0412,0,0,0,41.2452,33.0349ZM20,20A12,12,0,1,1,32,32,12.0137,12.0137,0,0,1,20,20ZM8.09,56A22.0293,22.0293,0,0,1,30,36h4A22.0293,22.0293,0,0,1,55.91,56Z"></path>
        </svg></span>';
    }
    if ( 'search' === $icon ) {
        return '<span class="base-svg-iconset"><svg id="i-search" class="thebase-svg-icon thebase-search-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32" class="base-svg-icon base-search-svg" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><circle cx="14" cy="14" r="12"></circle><path d="M23 23 L30 30"></path></svg></span>';
    }
    if ( 'header-wishlist' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="base-svg-icon base-header-wishlist-svg" fill="currentColor" stroke="currentColor" stroke-width="2" version="1.1" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 512 455.73"><title>Account</title><path d="M-427.29,383.85c-1.77,10-3,20.07-5.4,29.89-6.33,26-19,48.91-34.88,70.16-24.36,32.66-54,60.29-84.55,86.9q-54.48,47.43-109.35,94.41c-14,12-29,12.57-42.44.9-47.58-41.27-95.28-82.41-142.27-124.34-23.65-21.1-44.86-44.66-62.24-71.41-16.48-25.39-27.52-52.73-30.13-83.14a26.34,26.34,0,0,0-.74-3.37v-23c1.36-8.5,2.14-17.15,4.17-25.49C-921,277.21-887,237.79-827.84,222.56c7-1.81,14.36-2.52,21.55-3.74h22a5.91,5.91,0,0,0,1.74.8c36.36,3.81,65.31,21.27,89.07,48.3,3.46,3.94,6.72,8.07,10.32,12.42,2.18-2.79,4-5.18,5.84-7.48,19.34-23.67,42.83-41.3,72.71-49.38,7.32-2,14.87-3.13,22.32-4.66h22c1.61.3,3.24.55,4.84.89,9.59,2,19.52,3,28.7,6.17,51.11,17.71,81.36,54.43,94.44,106.08,2.4,9.45,3.38,19.25,5,28.88ZM-683.41,644.29c1.16-.92,1.83-1.42,2.45-2C-640.12,607-599,572-558.54,536.3c27.9-24.61,54.4-50.68,75.09-82,19.79-29.91,29.58-62.45,25.08-98.49-4.86-38.89-21.47-71.2-56-91.55-32.17-19-66.12-21.34-100.32-5-20.22,9.67-35.16,25.5-47.67,43.77-2,2.88-3.74,5.92-5.85,8.7-7.9,10.44-22.36,10.33-30.33-.14-7.46-9.78-14.26-20.18-22.58-29.17-18.58-20.08-41.6-32.05-69.26-33.44-50.68-2.55-95.25,28.54-111.12,76.86-15,45.76-8,88.31,18.17,128.18,16.3,24.84,36.29,46.56,58.21,66.34,33.87,30.6,68.48,60.39,102.84,90.44C-709.5,622.05-696.54,633-683.41,644.29Z" transform="translate(939.29 -218.82)"/>
        </svg></span>';
    }
    if ( 'menu3' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="base-svg-icon base-menu3-svg" fill="currentColor"  xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" id="Capa_1" x="0px" y="0px" viewBox="0 0 511.417 511.417" style="enable-background:new 0 0 511.417 511.417;" xml:space="preserve" width="27px" height="27px" class=""><g><g transform="matrix(1.25 0 0 -1.25 0 45)">
        <g>
            <g>
                <path style="fill:#D2A077;" d="M55.313-67.606c10.706,7.475,26.817,6.042,36.42-1.889L80.708-53.486     c-8.863,12.641-5.689,26.317,6.975,35.18c12.652,8.852,30.106,5.791,38.98-6.872l100.454-143.155l0.796,0.353L136.175-33.222     c-8.943,12.766-7.259,28.945,5.507,37.899c12.766,8.92,30.379,5.837,39.322-6.952L299.56-169.756     c8.943-12.777,4.562-30.276-8.203-39.219c-2.173-1.525-4.517-2.571-6.906-3.402v-103.868H170.672v35.419     c-1.673,1.468-11.002,8.681-12.322,10.57L48.361-107.178C39.339-94.332,42.456-76.617,55.313-67.606" data-original="#D2A077" class=""/>
                <path style="fill:#F3D2A2;" d="M30.669-160.779c0,0-12.88,18.773,5.905,31.642c18.762,12.868,31.63-5.905,31.63-5.905     l59.745-87.131c2.048,3.436,4.312,6.827,6.815,10.16L51.843-91.067c0,0-12.868,18.762,5.905,31.63     c18.762,12.88,31.63-5.894,31.63-5.894l78.006-113.744c2.901,2.378,5.86,4.745,8.932,7.077L85.897-40.129     c0,0-12.868,18.762,5.894,31.63c18.762,12.88,31.63-5.894,31.63-5.894l90.431-131.857c3.322,2.037,6.61,3.812,9.899,5.666     L139.247-17.339c0,0-12.868,18.762,5.905,31.63c18.762,12.88,31.63-5.894,31.63-5.894l89.361-130.321l7.157-10.433l6.428-9.387     c-56.297-38.605-61.656-111.263-29.491-158.174c6.44-9.387,15.826-2.958,15.826-2.958     c-38.616,56.309-26.817,119.58,29.491,158.185L278.921-61.61c0,0-6.201,21.902,15.69,28.103s28.092-15.69,28.092-15.69     l19.172-56.934c7.6-22.574,15.69-45.067,26.396-66.332c30.231-60.075,12.174-134.747-44.84-173.841     c-62.18-42.633-147.172-26.795-189.815,35.385c-2.253,3.3-4.142,6.519-5.939,9.739l-0.501-0.353L30.669-160.779z" data-original="#F3D2A2"/>
                <g>
                    <path style="fill:#838383" d="M136.539-328.1c-45.511,0-91.5,45.989-91.5,91.5c0,6.292-4.608,11.378-10.9,11.378      c-6.292,0-11.856-5.086-11.856-11.378c0-68.267,45.989-114.256,114.256-114.256c6.292,0,11.378,5.564,11.378,11.856      S142.831-328.1,136.539-328.1" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M79.65-350.378c-34.133,0-56.889,22.756-56.889,56.889c0,6.292-5.086,11.378-11.378,11.378      s-11.378-5.086-11.378-11.378c0-45.511,34.133-79.644,79.644-79.644c6.292,0,11.378,5.086,11.378,11.378      S85.942-350.378,79.65-350.378" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M273.072,13.711c-6.281,0-11.378-5.097-11.378-11.378s5.097-11.378,11.378-11.378      c45.511,0,91.022-40.835,91.022-91.022c0-6.281,5.097-11.378,11.378-11.378c6.281,0,11.378,5.097,11.378,11.378      C386.85-37.33,341.339,13.711,273.072,13.711" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M329.961,36c-6.281,0-11.378-4.619-11.378-10.9c0-6.292,5.097-11.856,11.378-11.856      c34.133,0,56.411-25.316,56.411-56.411c0-6.292,5.575-11.378,11.856-11.378c6.281,0,10.9,5.086,10.9,11.378      C409.128,0.479,375.472,36,329.961,36" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                </g>
            </g>
        </g>
    </g></g> </svg></span>';
    }
    return $output;
}

// Extra Footer Bottom Row
function theme_bottom_footer_widget ()  {
    echo '<div class="footer_bottom_top_row"><div class="site-container">';
        dynamic_sidebar('footer7');
    echo '</div></div>';
}
add_action( 'base_bottom_footer', 'theme_bottom_footer_widget' );