<?php
/**
 * Layout functions and definitions.
 * by TemplateMela.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 */


use function Base\webapp;
 
/*
 * Import Default Layout Styles
 *
 */
function kartpul_kids_enqueue_styles() {
    wp_enqueue_style( 'kartpul-kids-style',
        TMTHEME_URL . 'layouts/kids/style.css',
        array(),
        TMTHEME_VERSION
    );
    wp_enqueue_script( 'kartpul-kids-js',
        TMTHEME_URL . 'layouts/kids/custom.js',
        array(),
        TMTHEME_VERSION
    );
}

add_action(  'wp_enqueue_scripts', 'kartpul_kids_enqueue_styles' , 9999 );

/**
 * Setup Layout Theme Defaults
 *
 * @param array  registered option defaults with base theme.
 * @return array
 */
function kartpul_layout_change_option_defaults( $defaults ) {
    $new_defaults = '{
        "post_content_style": "unboxed"
    }';
    $new_defaults = json_decode( $new_defaults, true );
    return wp_parse_args( $new_defaults, $defaults );
}
//add_filter( 'base_theme_options_defaults', 'kartpul_layout_change_option_defaults', 20 );

/*
 * Set Default Logo
 * Filter the output of logo to fix Googles Error about itemprop logo
 */
add_filter( 'base_custom_logo', 'kartpul_set_default_logo', 10, 2 );
function kartpul_set_default_logo( $html, $blog_id ) {

	$custom_logo_id = webapp()->option( 'custom_logo' );
    // if logo is uploaded then return
    if ( ! empty($custom_logo_id) ) {
        return $html;
    }
    
    $custom_logo_path = TMTHEME_URL . 'layouts/kids/img/';
	$html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" itemprop="url">%2$s</a>',
        esc_url( home_url( '/' ) ),
        '<img decoding="async" width="170" height="34" src="' . $custom_logo_path . 'logo.svg"  class="logo" alt="' . get_bloginfo( 'name' ) . '" loading="lazy" srcset="' . $custom_logo_path . 'logo.svg 479w, ' . $custom_logo_path . 'logo.svg 200w" sizes="(max-width: 479px) 100vw, 479px" data-src="' . $custom_logo_path . 'logo.svg">');
        
        if ( webapp()->option( 'dark_mode_enable' ) && apply_filters( 'base_dark_mode_enable', true ) ) {
            $custom_logo_id = webapp()->option( 'dark_mode_logo' );
            // if dark logo is uploaded then return
            if ( ! empty($custom_logo_id) ) {
                return $html;
            }
            $html .= sprintf( '<a href="%1$s" class="brand" rel="home" itemprop="url">%2$s</a>',
            esc_url( home_url( '/' ) ),
            '<img decoding="async" width="170" height="34" src="' . $custom_logo_path . 'dark-logo.svg"  class="base-dark-mode-logo svg-logo-image logo" alt="' . get_bloginfo( 'name' ) . '" loading="lazy" srcset="' . $custom_logo_path . 'dark-logo.svg 479w, ' . $custom_logo_path . 'dark-logo.svg 200w" sizes="(max-width: 479px) 100vw, 479px" data-src="' . $custom_logo_path . 'dark-logo.svg">');

	    }
    return $html;	
}


// Override default theme icons
add_filter( 'base_svg_icon', 'kartpul_override_theme_icons', 10, 4 );
function kartpul_override_theme_icons( $output, $icon, $icon_title = '', $base = true, $aria = false ) {
    if ( 'shopping-cart' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="thebase-svg-icon thebase-shopping-cart-svg" fill="currentColor" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="24" height="24" viewBox="0 0 20 20">
        <path  d="M8 20c-1.103 0-2-0.897-2-2s0.897-2 2-2 2 0.897 2 2-0.897 2-2 2zM8 17c-0.551 0-1 0.449-1 1s0.449 1 1 1 1-0.449 1-1-0.449-1-1-1z"></path>
        <path  d="M15 20c-1.103 0-2-0.897-2-2s0.897-2 2-2 2 0.897 2 2-0.897 2-2 2zM15 17c-0.551 0-1 0.449-1 1s0.449 1 1 1 1-0.449 1-1-0.449-1-1-1z"></path>
        <path  d="M17.539 4.467c-0.251-0.297-0.63-0.467-1.039-0.467h-12.243l-0.099-0.596c-0.131-0.787-0.859-1.404-1.658-1.404h-1c-0.276 0-0.5 0.224-0.5 0.5s0.224 0.5 0.5 0.5h1c0.307 0 0.621 0.266 0.671 0.569l1.671 10.027c0.131 0.787 0.859 1.404 1.658 1.404h10c0.276 0 0.5-0.224 0.5-0.5s-0.224-0.5-0.5-0.5h-10c-0.307 0-0.621-0.266-0.671-0.569l-0.247-1.48 9.965-0.867c0.775-0.067 1.483-0.721 1.611-1.489l0.671-4.027c0.067-0.404-0.038-0.806-0.289-1.102zM16.842 5.404l-0.671 4.027c-0.053 0.316-0.391 0.629-0.711 0.657l-10.043 0.873-0.994-5.962h12.076c0.117 0 0.215 0.040 0.276 0.113s0.085 0.176 0.066 0.291z"></path>
        </svg>
        </span>';
    }
    if ( 'account' === $icon ) {
        return '<span class="base-svg-iconset"><svg version="1.1" class="thebase-svg-icon thebase-account-svg" fill="currentColor" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="24" height="24" viewBox="0 0 20 20">
        <path  d="M9.5 11c-3.033 0-5.5-2.467-5.5-5.5s2.467-5.5 5.5-5.5 5.5 2.467 5.5 5.5-2.467 5.5-5.5 5.5zM9.5 1c-2.481 0-4.5 2.019-4.5 4.5s2.019 4.5 4.5 4.5c2.481 0 4.5-2.019 4.5-4.5s-2.019-4.5-4.5-4.5z"></path>
        <path  d="M17.5 20h-16c-0.827 0-1.5-0.673-1.5-1.5 0-0.068 0.014-1.685 1.225-3.3 0.705-0.94 1.67-1.687 2.869-2.219 1.464-0.651 3.283-0.981 5.406-0.981s3.942 0.33 5.406 0.981c1.199 0.533 2.164 1.279 2.869 2.219 1.211 1.615 1.225 3.232 1.225 3.3 0 0.827-0.673 1.5-1.5 1.5zM9.5 13c-3.487 0-6.060 0.953-7.441 2.756-1.035 1.351-1.058 2.732-1.059 2.746 0 0.274 0.224 0.498 0.5 0.498h16c0.276 0 0.5-0.224 0.5-0.5-0-0.012-0.023-1.393-1.059-2.744-1.382-1.803-3.955-2.756-7.441-2.756z"></path>
        </svg></span>';
    }
    if ( 'search' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="thebase-svg-icon thebase-search-svg" fill="currentColor" version="1.1" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><title>Search</title><path d="M16.041 15.856c-0.034 0.026-0.067 0.055-0.099 0.087s-0.060 0.064-0.087 0.099c-1.258 1.213-2.969 1.958-4.855 1.958-1.933 0-3.682-0.782-4.95-2.050s-2.050-3.017-2.050-4.95 0.782-3.682 2.050-4.95 3.017-2.050 4.95-2.050 3.682 0.782 4.95 2.050 2.050 3.017 2.050 4.95c0 1.886-0.745 3.597-1.959 4.856zM21.707 20.293l-3.675-3.675c1.231-1.54 1.968-3.493 1.968-5.618 0-2.485-1.008-4.736-2.636-6.364s-3.879-2.636-6.364-2.636-4.736 1.008-6.364 2.636-2.636 3.879-2.636 6.364 1.008 4.736 2.636 6.364 3.879 2.636 6.364 2.636c2.125 0 4.078-0.737 5.618-1.968l3.675 3.675c0.391 0.391 1.024 0.391 1.414 0s0.391-1.024 0-1.414z"></path>
        </svg></span>';
    }
    if ( 'header-wishlist' === $icon ) {
        return '<span class="base-svg-iconset"><svg version="1.1" class="thebase-svg-icon thebase-wishlist-svg" fill="currentColor" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="24" height="24" viewBox="0 0 20 20">
        <path  d="M9.5 19c-0.084 0-0.167-0.021-0.243-0.063-0.094-0.052-2.326-1.301-4.592-3.347-1.341-1.21-2.411-2.448-3.183-3.68-0.984-1.571-1.482-3.139-1.482-4.66 0-2.895 2.355-5.25 5.25-5.25 0.98 0 2.021 0.367 2.931 1.034 0.532 0.39 0.985 0.86 1.319 1.359 0.334-0.499 0.787-0.969 1.319-1.359 0.91-0.667 1.951-1.034 2.931-1.034 2.895 0 5.25 2.355 5.25 5.25 0 1.521-0.499 3.089-1.482 4.66-0.771 1.232-1.842 2.47-3.182 3.68-2.266 2.046-4.498 3.295-4.592 3.347-0.076 0.042-0.159 0.063-0.243 0.063zM5.25 3c-2.343 0-4.25 1.907-4.25 4.25 0 3.040 2.35 5.802 4.321 7.585 1.76 1.592 3.544 2.708 4.179 3.087 0.635-0.379 2.419-1.495 4.179-3.087 1.971-1.782 4.321-4.545 4.321-7.585 0-2.343-1.907-4.25-4.25-4.25-1.703 0-3.357 1.401-3.776 2.658-0.068 0.204-0.259 0.342-0.474 0.342s-0.406-0.138-0.474-0.342c-0.419-1.257-2.073-2.658-3.776-2.658z"></path>
        </svg></span>';
    }
    if ( 'menu3' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="base-svg-icon base-menu3-svg" fill="currentColor"  xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" id="Capa_1" x="0px" y="0px" viewBox="0 0 511.417 511.417" style="enable-background:new 0 0 511.417 511.417;" xml:space="preserve" width="27px" height="27px" class=""><g><g transform="matrix(1.25 0 0 -1.25 0 45)">
        <g>
            <g>
                <path style="fill:#D2A077;" d="M55.313-67.606c10.706,7.475,26.817,6.042,36.42-1.889L80.708-53.486     c-8.863,12.641-5.689,26.317,6.975,35.18c12.652,8.852,30.106,5.791,38.98-6.872l100.454-143.155l0.796,0.353L136.175-33.222     c-8.943,12.766-7.259,28.945,5.507,37.899c12.766,8.92,30.379,5.837,39.322-6.952L299.56-169.756     c8.943-12.777,4.562-30.276-8.203-39.219c-2.173-1.525-4.517-2.571-6.906-3.402v-103.868H170.672v35.419     c-1.673,1.468-11.002,8.681-12.322,10.57L48.361-107.178C39.339-94.332,42.456-76.617,55.313-67.606" data-original="#D2A077" class=""/>
                <path style="fill:#F3D2A2;" d="M30.669-160.779c0,0-12.88,18.773,5.905,31.642c18.762,12.868,31.63-5.905,31.63-5.905     l59.745-87.131c2.048,3.436,4.312,6.827,6.815,10.16L51.843-91.067c0,0-12.868,18.762,5.905,31.63     c18.762,12.88,31.63-5.894,31.63-5.894l78.006-113.744c2.901,2.378,5.86,4.745,8.932,7.077L85.897-40.129     c0,0-12.868,18.762,5.894,31.63c18.762,12.88,31.63-5.894,31.63-5.894l90.431-131.857c3.322,2.037,6.61,3.812,9.899,5.666     L139.247-17.339c0,0-12.868,18.762,5.905,31.63c18.762,12.88,31.63-5.894,31.63-5.894l89.361-130.321l7.157-10.433l6.428-9.387     c-56.297-38.605-61.656-111.263-29.491-158.174c6.44-9.387,15.826-2.958,15.826-2.958     c-38.616,56.309-26.817,119.58,29.491,158.185L278.921-61.61c0,0-6.201,21.902,15.69,28.103s28.092-15.69,28.092-15.69     l19.172-56.934c7.6-22.574,15.69-45.067,26.396-66.332c30.231-60.075,12.174-134.747-44.84-173.841     c-62.18-42.633-147.172-26.795-189.815,35.385c-2.253,3.3-4.142,6.519-5.939,9.739l-0.501-0.353L30.669-160.779z" data-original="#F3D2A2"/>
                <g>
                    <path style="fill:#838383" d="M136.539-328.1c-45.511,0-91.5,45.989-91.5,91.5c0,6.292-4.608,11.378-10.9,11.378      c-6.292,0-11.856-5.086-11.856-11.378c0-68.267,45.989-114.256,114.256-114.256c6.292,0,11.378,5.564,11.378,11.856      S142.831-328.1,136.539-328.1" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M79.65-350.378c-34.133,0-56.889,22.756-56.889,56.889c0,6.292-5.086,11.378-11.378,11.378      s-11.378-5.086-11.378-11.378c0-45.511,34.133-79.644,79.644-79.644c6.292,0,11.378,5.086,11.378,11.378      S85.942-350.378,79.65-350.378" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M273.072,13.711c-6.281,0-11.378-5.097-11.378-11.378s5.097-11.378,11.378-11.378      c45.511,0,91.022-40.835,91.022-91.022c0-6.281,5.097-11.378,11.378-11.378c6.281,0,11.378,5.097,11.378,11.378      C386.85-37.33,341.339,13.711,273.072,13.711" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M329.961,36c-6.281,0-11.378-4.619-11.378-10.9c0-6.292,5.097-11.856,11.378-11.856      c34.133,0,56.411-25.316,56.411-56.411c0-6.292,5.575-11.378,11.856-11.378c6.281,0,10.9,5.086,10.9,11.378      C409.128,0.479,375.472,36,329.961,36" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                </g>
            </g>
        </g>
    </g></g> </svg></span>';
    }
    
    return $output;
}


// Woo Gallery Thumbnail Size
/* add_filter( 'woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
    return array(
        'width' => 150,
        'height' => 150,
        'crop' => 0,
    );
}); */

// Extra Footer Bottom Row
function theme_bottom_footer_widget ()  {
    echo '<div class="footer_bottom_top_row"><div class="site-container">';
        dynamic_sidebar('footer8');
    echo '</div></div>';
}
add_action( 'base_bottom_footer', 'theme_bottom_footer_widget' );