<?php
/**
 * Layout functions and definitions.
 * by TemplateMela.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 */

use function Base\webapp;

/*
 * tools Styles
 *
 */
function kartpul_tools_enqueue_styles() {
    wp_enqueue_style( 'kartpul-tools-style',
        TMTHEME_URL . 'layouts/tools/style.css',
        array(),
        TMTHEME_VERSION
    );
    wp_enqueue_script( 'kartpul-tools-js',
        TMTHEME_URL . 'layouts/tools/custom.js',
        array(),
        TMTHEME_VERSION
    );
}
add_action(  'wp_enqueue_scripts', 'kartpul_tools_enqueue_styles' , 9999 );

/**
 * Setup Layout Theme Defaults
 *
 * @param array  registered option defaults with base theme.
 * @return array
 */
function kartpul_layout_change_option_defaults( $defaults ) {
    $new_defaults = '{
        "post_content_style": "unboxed"
    }';
    $new_defaults = json_decode( $new_defaults, true );
    return wp_parse_args( $new_defaults, $defaults );
}
//add_filter( 'base_theme_options_defaults', 'kartpul_layout_change_option_defaults', 20 );

/*
 * Set Default Logo
 * Filter the output of logo to fix Googles Error about itemprop logo
 */
add_filter( 'base_custom_logo', 'kartpul_set_default_logo', 10, 2 );
function kartpul_set_default_logo( $html, $blog_id ) {

	$custom_logo_id = webapp()->option( 'custom_logo' );
    // if logo is uploaded then return
    if ( ! empty($custom_logo_id) ) {
        return $html;
    }
    $custom_logo_path = TMTHEME_URL . 'layouts/tools/img/';
	$html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" itemprop="url">%2$s</a>',
        esc_url( home_url( '/' ) ),
        '<img decoding="async" width="174" height="50" src="' . $custom_logo_path . 'logo.svg"  class="logo" alt="' . get_bloginfo( 'name' ) . '" loading="lazy" srcset="' . $custom_logo_path . 'logo.svg 479w, ' . $custom_logo_path . 'logo.svg 200w" sizes="(max-width: 479px) 100vw, 479px" data-src="' . $custom_logo_path . 'logo.svg">');
        
        if ( webapp()->option( 'dark_mode_enable' ) && apply_filters( 'base_dark_mode_enable', true ) ) {
            $custom_logo_id = webapp()->option( 'dark_mode_logo' );
            // if dark logo is uploaded then return
            if ( ! empty($custom_logo_id) ) {
                return $html;
            }
            $html .= sprintf( '<a href="%1$s" class="brand" rel="home" itemprop="url">%2$s</a>',
            esc_url( home_url( '/' ) ),
            '<img decoding="async" width="174" height="40" src="' . $custom_logo_path . 'dark-logo.svg"  class="base-dark-mode-logo logo svg-logo-image" alt="' . get_bloginfo( 'name' ) . '" loading="lazy" srcset="' . $custom_logo_path . 'dark-logo.svg 479w, ' . $custom_logo_path . 'dark-logo.svg 200w" sizes="(max-width: 479px) 100vw, 479px" data-src="' . $custom_logo_path . 'dark-logo.svg">');

	    }
    return $html;	
}

// Override default theme icons
add_filter( 'base_svg_icon', 'kartpul_override_theme_icons', 10, 4 );
function kartpul_override_theme_icons( $output, $icon, $icon_title = '', $base = true, $aria = false ) {
    if ( 'shopping-cart' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="thebase-svg-icon thebase-shopping-cart-svg" fill="currentColor" version="1.1" xmlns="http://www.w3.org/2000/svg" width="24" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="0.5" viewBox="0 0 762.47 673.5"><path d="M600.86,489.86a91.82,91.82,0,1,0,91.82,91.82A91.81,91.81,0,0,0,600.86,489.86Zm0,142.93a51.12,51.12,0,1,1,51.11-51.11A51.12,51.12,0,0,1,600.82,632.79Z" transform="translate(0 0)"/><path d="M458.62,561.33H393.3a91.82,91.82,0,1,0-.05,40.92h65.37a20.46,20.46,0,0,0,0-40.92ZM303.7,632.79a51.12,51.12,0,1,1,51.12-51.11A51.11,51.11,0,0,1,303.7,632.79Z" transform="translate(0 0)"/><path d="M762.47,129.41a17.26,17.26,0,0,0-17.26-17.26H260.87a17.18,17.18,0,0,0-13.26,6.23,20.47,20.47,0,0,0-7.22,19.22l31.16,208a20.46,20.46,0,0,0,40.34-6.86L284.18,153.79H718.89l-37,256.4H221.59L166.75,15.06A17.26,17.26,0,0,0,147.42.14L123.7.12l0,.13H20.26a20.26,20.26,0,0,0,0,40.52H129.34l52.32,376.91,1,8.87c.1.85.15,1.71.19,2.57a23,23,0,0,0,1.35,6.76l.05.39a17.25,17.25,0,0,0,19.33,14.89l23.74.25,0-.27H698.19a24.33,24.33,0,0,0,3.44-.25,17.25,17.25,0,0,0,18.43-14.66l.18-1.27A22.94,22.94,0,0,0,721.3,428l.8-6.5,40.06-288.46a16.23,16.23,0,0,0,.16-2.59Z" transform="translate(0 0)"/>
        </svg></span>';
    }
    if ( 'account' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="thebase-svg-icon thebase-account-svg" fill="currentColor" version="1.1" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 64 64"><title>Account</title><path d="M41.2452,33.0349a16,16,0,1,0-18.49,0A26.0412,26.0412,0,0,0,4,58a2,2,0,0,0,2,2H58a2,2,0,0,0,2-2A26.0412,26.0412,0,0,0,41.2452,33.0349ZM20,20A12,12,0,1,1,32,32,12.0137,12.0137,0,0,1,20,20ZM8.09,56A22.0293,22.0293,0,0,1,30,36h4A22.0293,22.0293,0,0,1,55.91,56Z"></path>
        </svg></span>';
    }
    if ( 'header-wishlist' === $icon ) {
        return '<span class="base-svg-iconset"><svg version="1.1" class="thebase-svg-icon thebase-wishlist-svg" fill="currentColor" stroke-width="0.2" stroke="currentColor" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="24" height="24" viewBox="0 0 20 20">
        <path d="M9.5 19c-0.084 0-0.167-0.021-0.243-0.063-0.094-0.052-2.326-1.301-4.592-3.347-1.341-1.21-2.411-2.448-3.183-3.68-0.984-1.571-1.482-3.139-1.482-4.66 0-2.895 2.355-5.25 5.25-5.25 0.98 0 2.021 0.367 2.931 1.034 0.532 0.39 0.985 0.86 1.319 1.359 0.334-0.499 0.787-0.969 1.319-1.359 0.91-0.667 1.951-1.034 2.931-1.034 2.895 0 5.25 2.355 5.25 5.25 0 1.521-0.499 3.089-1.482 4.66-0.771 1.232-1.842 2.47-3.182 3.68-2.266 2.046-4.498 3.295-4.592 3.347-0.076 0.042-0.159 0.063-0.243 0.063zM5.25 3c-2.343 0-4.25 1.907-4.25 4.25 0 3.040 2.35 5.802 4.321 7.585 1.76 1.592 3.544 2.708 4.179 3.087 0.635-0.379 2.419-1.495 4.179-3.087 1.971-1.782 4.321-4.545 4.321-7.585 0-2.343-1.907-4.25-4.25-4.25-1.703 0-3.357 1.401-3.776 2.658-0.068 0.204-0.259 0.342-0.474 0.342s-0.406-0.138-0.474-0.342c-0.419-1.257-2.073-2.658-3.776-2.658z"></path>
        </svg></span>';
    }
    if ( 'menu3' === $icon ) {
        return '<span class="base-svg-iconset"><svg class="base-svg-icon base-menu3-svg" fill="currentColor"  xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" id="Capa_1" x="0px" y="0px" viewBox="0 0 511.417 511.417" style="enable-background:new 0 0 511.417 511.417;" xml:space="preserve" width="27px" height="27px" class=""><g><g transform="matrix(1.25 0 0 -1.25 0 45)">
        <g>
            <g>
                <path style="fill:#D2A077;" d="M55.313-67.606c10.706,7.475,26.817,6.042,36.42-1.889L80.708-53.486     c-8.863,12.641-5.689,26.317,6.975,35.18c12.652,8.852,30.106,5.791,38.98-6.872l100.454-143.155l0.796,0.353L136.175-33.222     c-8.943,12.766-7.259,28.945,5.507,37.899c12.766,8.92,30.379,5.837,39.322-6.952L299.56-169.756     c8.943-12.777,4.562-30.276-8.203-39.219c-2.173-1.525-4.517-2.571-6.906-3.402v-103.868H170.672v35.419     c-1.673,1.468-11.002,8.681-12.322,10.57L48.361-107.178C39.339-94.332,42.456-76.617,55.313-67.606" data-original="#D2A077" class=""/>
                <path style="fill:#F3D2A2;" d="M30.669-160.779c0,0-12.88,18.773,5.905,31.642c18.762,12.868,31.63-5.905,31.63-5.905     l59.745-87.131c2.048,3.436,4.312,6.827,6.815,10.16L51.843-91.067c0,0-12.868,18.762,5.905,31.63     c18.762,12.88,31.63-5.894,31.63-5.894l78.006-113.744c2.901,2.378,5.86,4.745,8.932,7.077L85.897-40.129     c0,0-12.868,18.762,5.894,31.63c18.762,12.88,31.63-5.894,31.63-5.894l90.431-131.857c3.322,2.037,6.61,3.812,9.899,5.666     L139.247-17.339c0,0-12.868,18.762,5.905,31.63c18.762,12.88,31.63-5.894,31.63-5.894l89.361-130.321l7.157-10.433l6.428-9.387     c-56.297-38.605-61.656-111.263-29.491-158.174c6.44-9.387,15.826-2.958,15.826-2.958     c-38.616,56.309-26.817,119.58,29.491,158.185L278.921-61.61c0,0-6.201,21.902,15.69,28.103s28.092-15.69,28.092-15.69     l19.172-56.934c7.6-22.574,15.69-45.067,26.396-66.332c30.231-60.075,12.174-134.747-44.84-173.841     c-62.18-42.633-147.172-26.795-189.815,35.385c-2.253,3.3-4.142,6.519-5.939,9.739l-0.501-0.353L30.669-160.779z" data-original="#F3D2A2"/>
                <g>
                    <path style="fill:#838383" d="M136.539-328.1c-45.511,0-91.5,45.989-91.5,91.5c0,6.292-4.608,11.378-10.9,11.378      c-6.292,0-11.856-5.086-11.856-11.378c0-68.267,45.989-114.256,114.256-114.256c6.292,0,11.378,5.564,11.378,11.856      S142.831-328.1,136.539-328.1" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M79.65-350.378c-34.133,0-56.889,22.756-56.889,56.889c0,6.292-5.086,11.378-11.378,11.378      s-11.378-5.086-11.378-11.378c0-45.511,34.133-79.644,79.644-79.644c6.292,0,11.378,5.086,11.378,11.378      S85.942-350.378,79.65-350.378" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M273.072,13.711c-6.281,0-11.378-5.097-11.378-11.378s5.097-11.378,11.378-11.378      c45.511,0,91.022-40.835,91.022-91.022c0-6.281,5.097-11.378,11.378-11.378c6.281,0,11.378,5.097,11.378,11.378      C386.85-37.33,341.339,13.711,273.072,13.711" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                    <path style="fill:#838383" d="M329.961,36c-6.281,0-11.378-4.619-11.378-10.9c0-6.292,5.097-11.856,11.378-11.856      c34.133,0,56.411-25.316,56.411-56.411c0-6.292,5.575-11.378,11.856-11.378c6.281,0,10.9,5.086,10.9,11.378      C409.128,0.479,375.472,36,329.961,36" data-original="#77B255" class="active-path" data-old_color="#77B255"/>
                </g>
            </g>
        </g>
    </g></g> </svg></span>';
    }
    return $output;
}

// Extra Footer Bottom Row
function theme_bottom_footer_widget ()  {
    echo '<div class="footer_bottom_top_row"><div class="site-container">';
        dynamic_sidebar('footer7');
    echo '</div></div>';
}
add_action( 'base_bottom_footer', 'theme_bottom_footer_widget' );